==> qtjambi-remoteobjects-6.6.0-sources.jar: io/qt/remoteobjects/QRemoteObjectSourceLocationInfo.java <==
package io.qt.remoteobjects;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>QRemoteObjectSourceLocationInfo</code></p>
 */
public class QRemoteObjectSourceLocationInfo extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>QRemoteObjectSourceLocationInfo::<wbr>QRemoteObjectSourceLocationInfo()</code></p>
     */
    public QRemoteObjectSourceLocationInfo(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QRemoteObjectSourceLocationInfo instance);
    
    /**
     * <p>See <code>QRemoteObjectSourceLocationInfo::<wbr>QRemoteObjectSourceLocationInfo(QString,<wbr>QUrl)</code></p>
     */
    public QRemoteObjectSourceLocationInfo(java.lang.@NonNull String typeName_, io.qt.core.@NonNull QUrl hostUrl_){
        super((QPrivateConstructor)null);
        initialize_native(this, typeName_, hostUrl_);
    }
    
    private native static void initialize_native(QRemoteObjectSourceLocationInfo instance, java.lang.String typeName_, io.qt.core.QUrl hostUrl_);
    
    /**
     * <p>See <code>operator&lt;&lt;(QDataStream&amp;,<wbr>QRemoteObjectSourceLocationInfo)</code></p>
     */
    @QtUninvokable
    public void writeTo(io.qt.core.@StrictNonNull QDataStream stream){
        java.util.Objects.requireNonNull(stream, "Argument 'stream': null not expected.");
        writeTo_native_ref_QDataStream(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(stream));
    }
    
    @QtUninvokable
    private native void writeTo_native_ref_QDataStream(long __this__nativeId, long stream);
    
    /**
     * <p>See <code>QRemoteObjectSourceLocationInfo::<wbr>operator==(QRemoteObjectSourceLocationInfo)const</code></p>
     */
    @QtUninvokable
    private final boolean operator_equal(io.qt.remoteobjects.@NonNull QRemoteObjectSourceLocationInfo other){
        return operator_equal_native_cref_QRemoteObjectSourceLocationInfo_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native boolean operator_equal_native_cref_QRemoteObjectSourceLocationInfo_constfct(long __this__nativeId, long other);
    
    /**
     * <p>See <code>operator&gt;&gt;(QDataStream&amp;,<wbr>QRemoteObjectSourceLocationInfo&amp;)</code></p>
     */
    @QtUninvokable
    public void readFrom(io.qt.core.@StrictNonNull QDataStream stream){
        java.util.Objects.requireNonNull(stream, "Argument 'stream': null not expected.");
        readFrom_native_ref_QDataStream(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(stream));
    }
    
    @QtUninvokable
    private native void readFrom_native_ref_QDataStream(long __this__nativeId, long stream);
    
    /**
     * <p>See <code>QRemoteObjectSourceLocationInfo::<wbr>hostUrl</code></p>
     */
    @QtUninvokable
    public final void setHostUrl(io.qt.core.@NonNull QUrl hostUrl){
        setHostUrl_native_cref_QUrl(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(hostUrl));
    }
    
    @QtUninvokable
    private native void setHostUrl_native_cref_QUrl(long __this__nativeId, long hostUrl);
    
    /**
     * <p>See <code>QRemoteObjectSourceLocationInfo::<wbr>hostUrl</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl hostUrl(){
        return hostUrl_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl hostUrl_native(long __this__nativeId);
    
    /**
     * <p>See <code>QRemoteObjectSourceLocationInfo::<wbr>typeName</code></p>
     */
    @QtUninvokable
    public final void setTypeName(java.lang.@NonNull String typeName){
        setTypeName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), typeName);
    }
    
    @QtUninvokable
    private native void setTypeName_native_cref_QString(long __this__nativeId, java.lang.String typeName);
    
    /**
     * <p>See <code>QRemoteObjectSourceLocationInfo::<wbr>typeName</code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String typeName(){
        return typeName_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String typeName_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QRemoteObjectSourceLocationInfo(QPrivateConstructor p) { super(p); } 
    

    /**
     * <p>See <code>QRemoteObjectSourceLocationInfo::<wbr>operator==(QRemoteObjectSourceLocationInfo)const</code></p>
     */
    @Override
    @QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.remoteobjects.QRemoteObjectSourceLocationInfo) {
            return operator_equal((io.qt.remoteobjects.QRemoteObjectSourceLocationInfo) other);
        }

        return false;
    }


    /**
     * Returns the objects's hash code computed by <code>qHash(QRemoteObjectSourceLocationInfo)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);

    /**
     * <p>See <code>operator&lt;&lt;(QDebug,<wbr>QRemoteObjectSourceLocationInfo)</code></p>
     */
    @QtUninvokable
    @Override
    public @NonNull String toString() {
        return toString_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private static native String toString_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QRemoteObjectSourceLocationInfo clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QRemoteObjectSourceLocationInfo clone_native(long __this_nativeId);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #hostUrl()} instead.</p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl getHostUrl() {
        return hostUrl();
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #typeName()} instead.</p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String getTypeName() {
        return typeName();
    }
}

==> qtjambi-remoteobjects-6.7.1-sources.jar: io/qt/remoteobjects/QRemoteObjectSourceLocationInfo.java <==
package io.qt.remoteobjects;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>QRemoteObjectSourceLocationInfo</code></p>
 */
public class QRemoteObjectSourceLocationInfo extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>QRemoteObjectSourceLocationInfo::<wbr/>QRemoteObjectSourceLocationInfo()</code></p>
     */
    public QRemoteObjectSourceLocationInfo(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QRemoteObjectSourceLocationInfo instance);
    
    /**
     * <p>See <code>QRemoteObjectSourceLocationInfo::<wbr/>QRemoteObjectSourceLocationInfo(QRemoteObjectSourceLocationInfo)</code></p>
     */
    public QRemoteObjectSourceLocationInfo(io.qt.remoteobjects.@NonNull QRemoteObjectSourceLocationInfo other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QRemoteObjectSourceLocationInfo instance, io.qt.remoteobjects.QRemoteObjectSourceLocationInfo other);
    
    /**
     * <p>See <code>QRemoteObjectSourceLocationInfo::<wbr/>QRemoteObjectSourceLocationInfo(QString,<wbr/>QUrl)</code></p>
     */
    public QRemoteObjectSourceLocationInfo(java.lang.@NonNull String typeName_, io.qt.core.@NonNull QUrl hostUrl_){
        super((QPrivateConstructor)null);
        initialize_native(this, typeName_, hostUrl_);
    }
    
    private native static void initialize_native(QRemoteObjectSourceLocationInfo instance, java.lang.String typeName_, io.qt.core.QUrl hostUrl_);
    
    /**
     * <p>See <code>operator&lt;&lt;(QDataStream&amp;,<wbr/>QRemoteObjectSourceLocationInfo)</code></p>
     */
    @QtUninvokable
    public void writeTo(io.qt.core.@StrictNonNull QDataStream stream){
        java.util.Objects.requireNonNull(stream, "Argument 'stream': null not expected.");
        writeTo_native_ref_QDataStream(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(stream));
    }
    
    @QtUninvokable
    private native void writeTo_native_ref_QDataStream(long __this__nativeId, long stream);
    
    /**
     * <p>See <code>QRemoteObjectSourceLocationInfo::<wbr/>operator==(QRemoteObjectSourceLocationInfo)const</code></p>
     */
    @QtUninvokable
    public final boolean equals(io.qt.remoteobjects.@NonNull QRemoteObjectSourceLocationInfo other){
        return equals_native_cref_QRemoteObjectSourceLocationInfo_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native boolean equals_native_cref_QRemoteObjectSourceLocationInfo_constfct(long __this__nativeId, long other);
    
    /**
     * <p>See <code>operator&gt;&gt;(QDataStream&amp;,<wbr/>QRemoteObjectSourceLocationInfo&amp;)</code></p>
     */
    @QtUninvokable
    public void readFrom(io.qt.core.@StrictNonNull QDataStream stream){
        java.util.Objects.requireNonNull(stream, "Argument 'stream': null not expected.");
        readFrom_native_ref_QDataStream(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(stream));
    }
    
    @QtUninvokable
    private native void readFrom_native_ref_QDataStream(long __this__nativeId, long stream);
    
    /**
     * <p>See <code>QRemoteObjectSourceLocationInfo::<wbr/>hostUrl</code></p>
     */
    @QtUninvokable
    public final void setHostUrl(io.qt.core.@NonNull QUrl hostUrl){
        setHostUrl_native_cref_QUrl(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(hostUrl));
    }
    
    @QtUninvokable
    private native void setHostUrl_native_cref_QUrl(long __this__nativeId, long hostUrl);
    
    /**
     * <p>See <code>QRemoteObjectSourceLocationInfo::<wbr/>hostUrl</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl hostUrl(){
        return hostUrl_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl hostUrl_native(long __this__nativeId);
    
    /**
     * <p>See <code>QRemoteObjectSourceLocationInfo::<wbr/>typeName</code></p>
     */
    @QtUninvokable
    public final void setTypeName(java.lang.@NonNull String typeName){
        setTypeName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), typeName);
    }
    
    @QtUninvokable
    private native void setTypeName_native_cref_QString(long __this__nativeId, java.lang.String typeName);
    
    /**
     * <p>See <code>QRemoteObjectSourceLocationInfo::<wbr/>typeName</code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String typeName(){
        return typeName_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String typeName_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QRemoteObjectSourceLocationInfo(QPrivateConstructor p) { super(p); } 
    

    /**
     * <p>See <code>QRemoteObjectSourceLocationInfo::<wbr/>operator==(QRemoteObjectSourceLocationInfo)const</code></p>
     */
    @Override
    @QtUninvokable
    public boolean equals(Object other) {
        if (other==null || other instanceof io.qt.remoteobjects.QRemoteObjectSourceLocationInfo) {
            return equals((io.qt.remoteobjects.QRemoteObjectSourceLocationInfo) other);
        }

        return false;
    }


    /**
     * Returns the objects's hash code computed by <code>qHash(QRemoteObjectSourceLocationInfo)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);

    /**
     * <p>See <code>operator&lt;&lt;(QDebug,<wbr/>QRemoteObjectSourceLocationInfo)</code></p>
     */
    @QtUninvokable
    @Override
    public @NonNull String toString() {
        return toString_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private static native String toString_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
    <p>See <code>QRemoteObjectSourceLocationInfo::<wbr/>QRemoteObjectSourceLocationInfo(QRemoteObjectSourceLocationInfo)</code></p>
     */
    @QtUninvokable
    @Override
    public QRemoteObjectSourceLocationInfo clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QRemoteObjectSourceLocationInfo clone_native(long __this_nativeId);
    
    /**
     * <p>Overloaded constructor for {@link #QRemoteObjectSourceLocationInfo(java.lang.String, io.qt.core.QUrl)}.</p>
     */
    public QRemoteObjectSourceLocationInfo(java.lang.@NonNull String typeName_, java.lang.@NonNull String hostUrl_) {
        this(typeName_, new io.qt.core.QUrl(hostUrl_));
    }
    
    /**
     * <p>Overloaded function for {@link #setHostUrl(io.qt.core.QUrl)}.</p>
     */
    @QtUninvokable
    public final void setHostUrl(java.lang.@NonNull String hostUrl) {
        setHostUrl(new io.qt.core.QUrl(hostUrl));
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #hostUrl()} instead.</p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl getHostUrl() {
        return hostUrl();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #typeName()} instead.</p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String getTypeName() {
        return typeName();
    }
}
